==> django_simple_forums-1.0.7.tar.gz: django_simple_forums-1.0.7/simple_forums/utils.py <==
from django.conf import settings
from django.core.urlresolvers import reverse

from simple_forums import models


def get_setting(setting_name, default=None):
    """ Get the specified setting.

    If the setting exists, it will be returned. Otherwise, the default
    value will be returned.
    """
    settings_dict = getattr(settings, 'SIMPLE_FORUMS')

    if settings_dict:
        return settings_dict.get(setting_name, default)

    return default


def thread_detail_url(pk=None, thread=None):
    """ Get the url of a thread's detail view.

    Uses either the thread's pk or the thread instance itself to
    determine the url of the thread's detail view.
    """
    if pk is None and thread is None:
        raise ValueError("Either 'pk' or 'thread' must not be None")

    if pk:
        thread = models.Thread.objects.get(pk=pk)

    kwargs = {
        'topic_pk': thread.topic.pk,
        'topic_slug': thread.topic.slug,
        'thread_pk': thread.pk,
        'thread_slug': thread.slug,
    }

    return reverse('thread-detail', kwargs=kwargs)


def thread_list_url(topic_pk=None, topic=None):
    """ Get the url of the thread list view for a topic.

    Uses either the topic's pk or the topic instance itself to
    determine the url of the thread list view.
    """
    if topic_pk is None and topic is None:
        raise ValueError("Either 'topic_pk' or 'topic' must not be None")

    if topic_pk:
        topic = models.Topic.objects.get(pk=topic_pk)

    kwargs = {
        'topic_pk': topic.pk,
        'topic_slug': topic.slug,
    }

    return reverse('thread-list', kwargs=kwargs)

==> django_simple_forums-1.0.9.tar.gz: django_simple_forums-1.0.9/simple_forums/utils.py <==
from django.conf import settings
from django.core.urlresolvers import reverse

from simple_forums import models


def get_setting(setting_name, default=None):
    """ Get the specified setting.

    If the setting exists, it will be returned. Otherwise, the default
    value will be returned.
    """
    settings_dict = getattr(settings, 'SIMPLE_FORUMS', None)

    if settings_dict:
        return settings_dict.get(setting_name, default)

    return default


def thread_detail_url(pk=None, thread=None):
    """ Get the url of a thread's detail view.

    Uses either the thread's pk or the thread instance itself to
    determine the url of the thread's detail view.
    """
    if pk is None and thread is None:
        raise ValueError("Either 'pk' or 'thread' must not be None")

    if pk:
        thread = models.Thread.objects.get(pk=pk)

    kwargs = {
        'topic_pk': thread.topic.pk,
        'topic_slug': thread.topic.slug,
        'thread_pk': thread.pk,
        'thread_slug': thread.slug,
    }

    return reverse('thread-detail', kwargs=kwargs)


def thread_list_url(topic_pk=None, topic=None):
    """ Get the url of the thread list view for a topic.

    Uses either the topic's pk or the topic instance itself to
    determine the url of the thread list view.
    """
    if topic_pk is None and topic is None:
        raise ValueError("Either 'topic_pk' or 'topic' must not be None")

    if topic_pk:
        topic = models.Topic.objects.get(pk=topic_pk)

    kwargs = {
        'topic_pk': topic.pk,
        'topic_slug': topic.slug,
    }

    return reverse('thread-list', kwargs=kwargs)
